Documentation
¶
Overview ¶
Package utility is a generated GoMock package.
Package utility provides utility functions for the spotlike.
Package utility is a generated GoMock package.
Package utility is a generated GoMock package.
Package utility is a generated GoMock package.
Package utility is a generated GoMock package.
Index ¶
- func NewCapturer(os proxy.Os, stdBuffer proxy.Buffer, errBuffer proxy.Buffer) *capturer
- type Capturer
- type MockCapturer
- type MockCapturerMockRecorder
- type MockPromptUtil
- type MockPromptUtilMockRecorder
- type MockStringsUtil
- type MockStringsUtilMockRecorder
- type MockTableWriterUtil
- type MockTableWriterUtilMockRecorder
- type MockVersionUtil
- type MockVersionUtilMockRecorder
- type PromptUtil
- type StringsUtil
- type TableWriterUtil
- type VersionUtil
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type MockCapturer ¶
type MockCapturer struct {
// contains filtered or unexported fields
}
MockCapturer is a mock of Capturer interface.
func NewMockCapturer ¶
func NewMockCapturer(ctrl *gomock.Controller) *MockCapturer
NewMockCapturer creates a new mock instance.
func (*MockCapturer) CaptureOutput ¶
func (m *MockCapturer) CaptureOutput(fnc func()) (string, string, error)
CaptureOutput mocks base method.
func (*MockCapturer) EXPECT ¶
func (m *MockCapturer) EXPECT() *MockCapturerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockCapturerMockRecorder ¶
type MockCapturerMockRecorder struct {
// contains filtered or unexported fields
}
MockCapturerMockRecorder is the mock recorder for MockCapturer.
func (*MockCapturerMockRecorder) CaptureOutput ¶
func (mr *MockCapturerMockRecorder) CaptureOutput(fnc any) *gomock.Call
CaptureOutput indicates an expected call of CaptureOutput.
type MockPromptUtil ¶
type MockPromptUtil struct {
// contains filtered or unexported fields
}
MockPromptUtil is a mock of PromptUtil interface.
func NewMockPromptUtil ¶
func NewMockPromptUtil(ctrl *gomock.Controller) *MockPromptUtil
NewMockPromptUtil creates a new mock instance.
func (*MockPromptUtil) EXPECT ¶
func (m *MockPromptUtil) EXPECT() *MockPromptUtilMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
type MockPromptUtilMockRecorder ¶
type MockPromptUtilMockRecorder struct {
// contains filtered or unexported fields
}
MockPromptUtilMockRecorder is the mock recorder for MockPromptUtil.
type MockStringsUtil ¶
type MockStringsUtil struct {
// contains filtered or unexported fields
}
MockStringsUtil is a mock of StringsUtil interface.
func NewMockStringsUtil ¶
func NewMockStringsUtil(ctrl *gomock.Controller) *MockStringsUtil
NewMockStringsUtil creates a new mock instance.
func (*MockStringsUtil) EXPECT ¶
func (m *MockStringsUtil) EXPECT() *MockStringsUtilMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockStringsUtil) RemoveNewLines ¶
func (m *MockStringsUtil) RemoveNewLines(s string) string
RemoveNewLines mocks base method.
func (*MockStringsUtil) RemoveSpaces ¶
func (m *MockStringsUtil) RemoveSpaces(s string) string
RemoveSpaces mocks base method.
func (*MockStringsUtil) RemoveTabs ¶
func (m *MockStringsUtil) RemoveTabs(s string) string
RemoveTabs mocks base method.
type MockStringsUtilMockRecorder ¶
type MockStringsUtilMockRecorder struct {
// contains filtered or unexported fields
}
MockStringsUtilMockRecorder is the mock recorder for MockStringsUtil.
func (*MockStringsUtilMockRecorder) RemoveNewLines ¶
func (mr *MockStringsUtilMockRecorder) RemoveNewLines(s any) *gomock.Call
RemoveNewLines indicates an expected call of RemoveNewLines.
func (*MockStringsUtilMockRecorder) RemoveSpaces ¶
func (mr *MockStringsUtilMockRecorder) RemoveSpaces(s any) *gomock.Call
RemoveSpaces indicates an expected call of RemoveSpaces.
func (*MockStringsUtilMockRecorder) RemoveTabs ¶
func (mr *MockStringsUtilMockRecorder) RemoveTabs(s any) *gomock.Call
RemoveTabs indicates an expected call of RemoveTabs.
type MockTableWriterUtil ¶
type MockTableWriterUtil struct {
// contains filtered or unexported fields
}
MockTableWriterUtil is a mock of TableWriterUtil interface.
func NewMockTableWriterUtil ¶
func NewMockTableWriterUtil(ctrl *gomock.Controller) *MockTableWriterUtil
NewMockTableWriterUtil creates a new mock instance.
func (*MockTableWriterUtil) EXPECT ¶
func (m *MockTableWriterUtil) EXPECT() *MockTableWriterUtilMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockTableWriterUtil) GetNewDefaultTable ¶
func (m *MockTableWriterUtil) GetNewDefaultTable(writer io.Writer) proxy.Table
GetNewDefaultTable mocks base method.
type MockTableWriterUtilMockRecorder ¶
type MockTableWriterUtilMockRecorder struct {
// contains filtered or unexported fields
}
MockTableWriterUtilMockRecorder is the mock recorder for MockTableWriterUtil.
func (*MockTableWriterUtilMockRecorder) GetNewDefaultTable ¶
func (mr *MockTableWriterUtilMockRecorder) GetNewDefaultTable(writer any) *gomock.Call
GetNewDefaultTable indicates an expected call of GetNewDefaultTable.
type MockVersionUtil ¶
type MockVersionUtil struct {
// contains filtered or unexported fields
}
MockVersionUtil is a mock of VersionUtil interface.
func NewMockVersionUtil ¶
func NewMockVersionUtil(ctrl *gomock.Controller) *MockVersionUtil
NewMockVersionUtil creates a new mock instance.
func (*MockVersionUtil) EXPECT ¶
func (m *MockVersionUtil) EXPECT() *MockVersionUtilMockRecorder
EXPECT returns an object that allows the caller to indicate expected use.
func (*MockVersionUtil) GetVersion ¶
func (m *MockVersionUtil) GetVersion(version string) string
GetVersion mocks base method.
type MockVersionUtilMockRecorder ¶
type MockVersionUtilMockRecorder struct {
// contains filtered or unexported fields
}
MockVersionUtilMockRecorder is the mock recorder for MockVersionUtil.
func (*MockVersionUtilMockRecorder) GetVersion ¶
func (mr *MockVersionUtilMockRecorder) GetVersion(version any) *gomock.Call
GetVersion indicates an expected call of GetVersion.
type PromptUtil ¶
func NewPromptUtil ¶
func NewPromptUtil( promptui proxy.Promptui, ) PromptUtil
NewPromptUtil returns a new instance of the promptUtil struct.
type StringsUtil ¶
type StringsUtil interface {
RemoveNewLines(s string) string
RemoveSpaces(s string) string
RemoveTabs(s string) string
}
StringsUtil is an interface that contains the utility functions for manipulating strings.
func NewStringsUtil ¶
func NewStringsUtil() StringsUtil
NewStringsUtil returns a new instance of the StringsUtil struct.
type TableWriterUtil ¶
TableWriterUtil is an interface that contains the utility functions for writing tables.
func NewTableWriterUtil ¶
func NewTableWriterUtil(tableWriter proxy.TableWriter) TableWriterUtil
NewTableWriterUtil returns a new instance of the TableWriterUtil interface.
type VersionUtil ¶
VersionUtil is an interface that provides the version of the application.
func NewVersionUtil ¶
func NewVersionUtil( debug proxy.Debug, ) VersionUtil
NewVersionUtil returns a new instance of the versionUtil struct.